@@ -8,14 +8,12 @@ from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusQAxWidgetMixin imp
     KiwoomOpenApiPlusQAxWidgetMixin,
 )
 from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusSignalConnector import (
-    KiwoomOpenApiPlusOnReceiveRealDataSignalConnector,
     KiwoomOpenApiPlusSignalConnector,
 )
 from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusSignature import (
     KiwoomOpenApiPlusDispatchSignature,
     KiwoomOpenApiPlusEventHandlerSignature,
 )
-from koapy.compat.pyside2 import PYQT5, PYSIDE2, PythonQtError
 from koapy.compat.pyside2.QtAxContainer import QAxWidget
 from koapy.compat.pyside2.QtCore import QEvent, Qt
 from koapy.compat.pyside2.QtWidgets import QWidget
@@ -35,14 +33,6 @@ class KiwoomOpenApiPlusQAxWidget(QWidgetLogging, KiwoomOpenApiPlusQAxWidgetMixin
         # Check 32bit requirement
         assert is_32bit(), "Control object should be created in 32bit environment"
 
-        # Check Qt backend
-        if PYQT5:
-            self.logger.debug("Using PyQt5 as Qt backend")
-        elif PYSIDE2:
-            self.logger.debug("Using PySide2 as Qt backend")
-        else:
-            raise PythonQtError("No Qt bindings could be found")
-
         # Process arguments
         control = None
         parent = None
@@ -69,9 +59,8 @@ class KiwoomOpenApiPlusQAxWidget(QWidgetLogging, KiwoomOpenApiPlusQAxWidgetMixin
         if control is None:
             control = self.CLSID
 
-        # Call super inits
+        # Call super init
         QWidgetLogging.__init__(self, *args, **kwargs)
-        KiwoomOpenApiPlusQAxWidgetMixin.__init__(self)
 
         # Create QAxWidget
         self._control = control
@@ -86,22 +75,20 @@ class KiwoomOpenApiPlusQAxWidget(QWidgetLogging, KiwoomOpenApiPlusQAxWidgetMixin
 
         # Set methods as attributes
         for method_name in self.METHOD_NAMES:
-            dynamic_callable = KiwoomOpenApiPlusDynamicCallable(self._ax, method_name)
+            dynamic_callable = KiwoomOpenApiPlusDynamicCallable(
+                self._ax, method_name, parent=self
+            )
             setattr(self, method_name, dynamic_callable)
 
         # Set signals as attributes
         for event_name in self.EVENT_NAMES:
-            if event_name == "OnReceiveRealData":
-                signal_connector = KiwoomOpenApiPlusOnReceiveRealDataSignalConnector(
-                    self
-                )
-                self.DelayedSetRealReg = signal_connector.SetRealReg
-                self.DelayedSetRealRemove = signal_connector.SetRealRemove
-            else:
-                signal_connector = KiwoomOpenApiPlusSignalConnector(event_name)
+            signal_connector = KiwoomOpenApiPlusSignalConnector(event_name)
             signal_connector.connect_to(self._ax)
             setattr(self, event_name, signal_connector)
 
+        # Call mixin init here, after method attributes are set
+        KiwoomOpenApiPlusQAxWidgetMixin.__init__(self)
+
         # Enable logging for QAxWidget exceptions
         self._ax.exception.connect(self._onException)  # pylint: disable=no-member
 
