@@ -1,11 +1,11 @@
 import sys
 
-from PyQt5.QtWidgets import QApplication
 from PyQt5.QAxContainer import QAxWidget
+from PyQt5.QtWidgets import QApplication
 
 app = QApplication(sys.argv)
-control = QAxWidget('{A1574A0D-6BFA-4BD7-9020-DED88711818D}')
+control = QAxWidget("{A1574A0D-6BFA-4BD7-9020-DED88711818D}")
 
-APIModulePath = control.dynamicCall('GetAPIModulePath()')
+APIModulePath = control.dynamicCall("GetAPIModulePath()")
 
 print(APIModulePath)
